==> hlw-core-0.0.2-20250422.075438-9-sources.jar: cn/gtmap/hlw/core/dto/third/cqxx/page/BdcdyxxPageThirdQueryResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqxx.page;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
 * @version 2024/1/18 10:09
 * @description 不动产单元信息分页查询出参
 */
@Data
public class BdcdyxxPageThirdQueryResultDTO implements Serializable {

    /**
     * 入参区域代码（前端传入的区域代码）
     */
    private String rcqydm;

    /**
     * 不动产单元号
     */
    private String bdcdyh;

    /**
     * 坐落
     */
    private String zl;

    /**
     * 产权证号
     */
    private String cqzh;

    /**
     * 房屋面积
     */
    private String mj;

    /**
     * 是否抵押（0是，1否）
     */
    private String sfdy;

    /**
     * 是否查封（0是，1否）
     */
    private String sfcf;

    /**
     * 不动产单元编号
     */
    private String bdcdybh;

    /**
     * 宗地宗海面积
     */
    private String zdmj;

    /**
     * 宗地用途
     */
    private String tdyt;

    /**
     * 宗地用途名称
     */
    private String tdytmc;

    /**
     * 宗地权利性质
     */
    private String zdzhqlxz;

    /**
     * 宗地权利性质名称
     */
    private String zdzhqlxzmc;

    /**
     * 房屋结构
     */
    private String fwjg;

    /**
     * 房屋结构名称
     */
    private String fwjgmc;

    /**
     * 总层数
     */
    private String fwzcs;

    /**
     * 所在层
     */
    private String fwszc;

    /**
     * 房屋性质
     */
    private String fwxz;

    /**
     * 房屋性质名称
     */
    private String fwxzmc;

    /**
     * 房屋类型
     */
    private String fwlx;

    /**
     * 房屋类型名称
     */
    private String fwlxmc;

    /**
     * 规划用途
     */
    private String ghyt;

    /**
     * 规划用途代码
     */
    private String ghytdm;

    /**
     * 宗地用途
     */
    private String zdyt;

    /**
     * 宗地用途代码
     */
    private String zdytdm;

    /**
     * 宗地用途名称
     */
    private String zdytmc;

    /**
     * 规划用途名称
     */
    private String ghytmc;

    /**
     * 证书来源
     */
    private String zsly;

    /**
     * 不动产类型
     */
    private String bdclx;

    /**
     * 不动产类型名称
     */
    private String bdclxmc;

    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;

    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;

    /**
     * 土地使用权人
     */
    private String tdsyqr;

    /**
     * 权利人信息
     */
    private List<BdcdyxxPageThirdQueryQlrResultDTO> qlrList;

    /**
     * 关联土地证信息
     */
    private List<BdcdyxxPageThirdQueryGltdzxxResultDTO> gltdzxx;

    /**
     * 登记时间
     */
    private String djsj;
    /**
     * 区域代码
     */
    private String qydm;
}

==> hlw-core-0.0.2-20250711.025037-103-sources.jar: cn/gtmap/hlw/core/dto/third/cqxx/page/BdcdyxxPageThirdQueryResultDTO.java <==
package cn.gtmap.hlw.core.dto.third.cqxx.page;

import lombok.Data;

import java.io.Serializable;
import java.util.List;

/**
 * @author <a href="mailto:wangzhiwen@gtmap.cn">wangzhiwen</a>
 * @version 2024/1/18 10:09
 * @description 不动产单元信息分页查询出参
 */
@Data
public class BdcdyxxPageThirdQueryResultDTO implements Serializable {

    /**
     * 入参区域代码（前端传入的区域代码）
     */
    private String rcqydm;

    /**
     * 不动产单元号
     */
    private String bdcdyh;

    /**
     * 坐落
     */
    private String zl;

    /**
     * 产权证号
     */
    private String cqzh;

    /**
     * 房屋面积
     */
    private String mj;

    /**
     * 是否抵押（0是，1否）
     */
    private String sfdy;

    /**
     * 是否查封（0是，1否）
     */
    private String sfcf;

    /**
     * 不动产单元编号
     */
    private String bdcdybh;

    /**
     * 宗地宗海面积
     */
    private String zdmj;

    /**
     * 宗地用途
     */
    private String tdyt;

    /**
     * 宗地用途名称
     */
    private String tdytmc;

    /**
     * 宗地权利性质
     */
    private String zdzhqlxz;

    /**
     * 宗地权利性质名称
     */
    private String zdzhqlxzmc;

    /**
     * 房屋结构
     */
    private String fwjg;

    /**
     * 房屋结构名称
     */
    private String fwjgmc;

    /**
     * 总层数
     */
    private String fwzcs;

    /**
     * 所在层
     */
    private String fwszc;

    /**
     * 房屋性质
     */
    private String fwxz;

    /**
     * 房屋性质名称
     */
    private String fwxzmc;

    /**
     * 房屋类型
     */
    private String fwlx;

    /**
     * 房屋类型名称
     */
    private String fwlxmc;

    /**
     * 规划用途
     */
    private String ghyt;

    /**
     * 规划用途代码
     */
    private String ghytdm;

    /**
     * 宗地用途
     */
    private String zdyt;

    /**
     * 宗地用途代码
     */
    private String zdytdm;

    /**
     * 宗地用途名称
     */
    private String zdytmc;

    /**
     * 规划用途名称
     */
    private String ghytmc;

    /**
     * 证书来源
     */
    private String zsly;

    /**
     * 不动产类型
     */
    private String bdclx;

    /**
     * 不动产类型名称
     */
    private String bdclxmc;

    /**
     * 土地使用起始时间
     */
    private String tdsyqssj;

    /**
     * 土地使用结束时间
     */
    private String tdsyjssj;

    /**
     * 土地使用权人
     */
    private String tdsyqr;

    /**
     * 权利人信息
     */
    private List<BdcdyxxPageThirdQueryQlrResultDTO> qlrList;

    /**
     * 关联土地证信息
     */
    private List<BdcdyxxPageThirdQueryGltdzxxResultDTO> gltdzxx;

    /**
     * 登记时间
     */
    private String djsj;
    /**
     * 区域代码
     */
    private String qydm;
    /**
     * 是否异议
     */
    private String sfyy;
    /**
     * 是否预告
     */
    private String sfyg;
    /**
     * 是否锁定
     */
    private String sfsd;
    /**
     * 分摊面积
     */
    private String ftmj;
    /**
     * 套内面积
     */
    private String tnmj;
    /**
     * 建筑年代
     */
    private String jznd;
    /**
     * 自然幢号
     */
    private String zrzh;
}
